#
# spec file for package mono-debugger
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           mono-debugger
Summary:        Mono Debugger
License:        GPL-2.0+ and LGPL-2.0+ and MIT
Group:          Development/Languages/Mono
Url:            http://www.mono-project.com/Debugger
Version:        2.10
Release:        21.1
Source:         http://download.mono-project.com/sources/mono-debugger/%{name}-%{version}.tar.bz2
Source99:       mono-debugger-rpmlintrc
Patch1:         mono-debugger-glib.patch
Patch2:         mono-v4-install.patch
ExclusiveArch:  %ix86 x86_64
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       mono-core >= 2.7
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  glib2-devel
BuildRequires:  libmono-2_0-devel
BuildRequires:  libtool
BuildRequires:  mono-devel
BuildRequires:  mono-nunit
BuildRequires:  ncurses-devel

%description
A debugger is an important tool for development. The Mono Debugger
(MDB) can debug both managed and unmanaged applications.  It provides a
reusable library that can be used to add debugger functionality to
different front-ends. The debugger package includes a console debugger
named "mdb", and MonoDevelop (http://www.monodevelop.com) provides a
GUI interface to the debugger.

%define mcsver %({ mcs --version | awk '{print $5}' | cut -f1 -d"." ; mcs --version | awk '{print $5}' | cut -f2 -d"." ; } | xargs printf "%03d")

%if 0%{?mcsver} >= 4000
%define target_dir 4.5
%else
%define target_dir 2.0
%endif

%files
%defattr(-, root, root)
%doc AUTHORS COPYING ChangeLog README NEWS
%{_bindir}/mdb*
%{_libdir}/*.so*
%{_prefix}/lib/mono/%{target_dir}/mdb*.exe
%{_prefix}/lib/mono/gac/Mono.Debugger*
%{_prefix}/lib/mono/mono-debugger
%{_libdir}/pkgconfig/mono-debugger*.pc

%prep
%setup -q
%patch1 -p1
%if 0%{?mcsver} >= 4000
%patch2 -p1
%endif

%build
%if 0%{?mcsver} >= 4000
export MCS="/usr/bin/mcs"
%endif

autoreconf -fiv
%configure
make

%install
make install DESTDIR=%{buildroot}
# Unset executable bit on .exe files
# This prevents the dbuginfo macros from scanning them
find %{buildroot} -name '*.exe' -exec chmod a-x '{}' ';'
find %{buildroot} -name '*.dll' -exec chmod a-x '{}' ';'
# Remove unnecessary devel files
rm -f %{buildroot}%_libdir/*.la
rm -f %{buildroot}%_libdir/*.a

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%changelog
* Tue Jun  7 2016 fwdsbs.to.11df@xoxy.net
- Added mono-v4-install.patch in order to fix install location and nunit-console.exe path:
  * Fix mdb startup crash when compiled with mono v4.0 and up (mcs -sdk:4.5)
- Alter files section in spec file depending of mcs version:
  * Fix build issue with mono v4.4 and up
* Thu Jun 11 2015 dimstar@opensuse.org
- Add mono-debugger-rpmlintrc to source list, so the package can
  be submitted to Factory again.
* Tue May  5 2015 fwdsbs.to.11df@xoxy.net
- fix build with Mono 4
* Sat Nov 17 2012 ro@suse.de
- fix check-build.sh for kernel > 3.0
* Thu Mar  1 2012 aj@suse.de
- Fix build with current glib.
* Tue Feb 22 2011 ajorgensen@novell.com
- Update to 2.10
  * http://www.go-mono.com/archive/2.10
* Fri Jan  7 2011 ajorgensen@novell.com
- Update to 2.8.1
  * http://www.go-mono.com/archive/2.8.1
* Wed Nov  3 2010 ajorgensen@novell.com
- Update to 2.8
  * http://www.go-mono.com/archive/2.8
* Sun May  9 2010 aj@suse.de
- Fix build with requiring glib2-devel.
* Tue Mar 16 2010 ajorgensen@novell.com
- Update to 2.6.3
  * http://www.mono-project.com/Release_Notes_Mono_2.6.3
* Tue Jan 26 2010 ajorgensen@novell.com
- Update to 2.6
  * http://www.mono-project.com/Release_Notes_Mono_2.6
* Tue Aug 11 2009 ajorgensen@novell.com
- Update to 2.4.2.1
  * http://www.mono-project.com/Release_Notes_Mono_2.4.2.1
* Tue Mar 31 2009 ajorgensen@novell.com
- Update to 2.4
  * http://www.mono-project.com/Release_Notes_Mono_2.4
* Fri Nov 21 2008 ro@suse.de
- update check-build.sh
* Thu Oct 23 2008 ajorgensen@novell.com
- Require >= 2.0 of mono (mono got updated to 2.0.1)
* Wed Sep 10 2008 ajorgensen@novell.com
- Update to 2.0 RC2
  * Revert some breakpoint handler changes
* Tue Sep  2 2008 ajorgensen@novell.com
- Update to 2.0-RC1
* Mon Sep  1 2008 ro@suse.de
- respect CFLAGS setting (for RPM_OPT_FLAGS)
  (patch present but disabled, too many errors)
- make term.c include ncurses/termcap.h to fix build
* Tue Aug 26 2008 ajorgensen@novell.com
- Update to 2.0
  * Will be released with Mono going forward to ensure compatibility
  * Many bugfixes
* Tue May  6 2008 aj@suse.de
- Use <sys/users.h> to fix build.
* Mon Jan 14 2008 wberrier@novell.com
- Update to 0.60
  - Updated to run with mono 1.2.6 runtime
  - Various bux fixes
* Sat Jun  9 2007 wberrier@novell.com
- Add post/un ldconfig scripts
- Update to 0.50
  - Lots of bug-fixes, usability improvements and increased stability.
  - New object formatter:
  When printing a class object, we now include fields from its parents.
  - Added support for Displays (thanks to Massimiliano Mantione).
  - New threading model:
  By default, all threads are now stopped when the debugger is in
  control.
  - Ctrl-C now stops all threads.
  - We now support stripped `mono' binaries.
* Fri Apr 13 2007 wberrier@novell.com
- add %%debug_package so debug packages get created
* Wed Apr 11 2007 wberrier@novell.com
- Add mono dep/req for older distros
* Wed Apr  4 2007 wberrier@novell.com
- Adapt for buildservice
* Wed Dec  6 2006 dmueller@suse.de
- don't build as root
* Tue Nov 14 2006 wberrier@suse.de
- Update to 0.31
  - (contains a gpl friendly libedit)
- Remove old patches
- mono-debugger_libedit_cast.patch: castings for new libedit
* Wed Aug 30 2006 wberrier@suse.de
- Update to 0.30.  Add requires mono-core >= 1.1.16
- 0.30 Changes:
  - Redesigned and improved the session code.
  - Stability improvements and bug fixes.
  - Fixed i386 support.
- 0.20 Changes:
  - We now preserve breakpoints across different invocations of
  the same target.
  - Big API cleanups.
  - Cleaned up method lookups; there's a very complex test for them
  in test/testsuite/TestMethodLookup.cs.
  - Lots of stability improvements.
  - Fixed a very old GC bug which was preventing us from running
  xsp inside the debugger.
  - Fixed a very old race condition which was causing crashes at exit.
  - Fixed line numbers in stack traces.
  - Added experimental support for hardware watchpoints - I needed
  them to track down a race condition.
- 0.13 Changes:
  - The test suite has been migrated to NUnit.
  - Multi-Process support: The debugger can now follow fork()s
  and exec()s and thus debug multiple processes at the same time.
- 0.12 Changes:
  - The debugger no longer uses a `mono-debugger-mini-wrapper',
  it's now using the normal `mono' instead.
  - We can now attach to processes and examine core files -
  this still needs some testing; bug reports are very welcome ...
  - We no longer run the backend in another process/appdomain;
  most of the remoting stuff is gone to make the debugger faster
  and more reliable.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Dec 22 2005 wberrier@suse.de
- Clean up spec, update to 0.11, add NULL patch for libedit, only
  build on x86 and x86_64
* Mon Aug 29 2005 aj@suse.de
- Add check-build.sh.
* Tue Aug  2 2005 ro@suse.de
- make it build ...
* Tue Jul 19 2005 wberrier@suse.de
- Initial submission
